@@ -1,14 +1,16 @@
 export default class Warning extends Error {
   constructor(warning) {
     super(warning);
+
     const { text, line, column } = warning;
-    this.name = 'Warning';
+
+    this.name = "Warning";
 
     // Based on https://github.com/postcss/postcss/blob/master/lib/warning.es6#L74
     // We don't need `plugin` properties.
     this.message = `${this.name}\n\n`;
 
-    if (typeof line !== 'undefined') {
+    if (typeof line !== "undefined") {
       this.message += `(${line}:${column}) `;
     }
 
