@@ -1,5 +1,5 @@
 export default function loader(content, map) {
   const callback = this.async();
 
-  return callback(null, content, map, 'non-ast-meta');
+  return callback(null, content, map, "non-ast-meta");
 }
